<?php

namespace Buckhill\Net\tests\units;

use mageekguy\atoum;
use Buckhill\Net\MAC as MACAddr;
use function Buckhill\Net\getmacaddr;

class MAC extends atoum
{
    public function testSomething()
    {
        $this
            ->given($mac = new MACAddr())
            ->then
                ->object($mac)->isInstanceOf(MACAddr::class)
                ->array($mac->getInterfaces())->isNotEmpty()
                ->array($mac->getMAC())->isNotEmpty()
                ->array(getmacaddr())->isNotEmpty()
            ;
    }
}