<?php

namespace Buckhill\Net;

/**
 * @return array
 */
function getmacaddr()
{
    $mac = new MAC();

    return $mac->getMAC();
}

/**
 * @return array
 */
function getinterfaces()
{
    $net = new Network();

    return $net->getInterfaces();
}